<?php

declare(strict_types=1);

namespace Drupal\date_point\Plugin\Field\FieldFormatter\DateTime;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\date_point\Plugin\Field\FieldType\DateTime\DateTimeItem;

/**
 * Plugin implementation of the 'Plain' formatter for 'datetime' fields.
 *
 * @FieldFormatter(
 *   id = "dp_date_time_plain",
 *   label = @Translation("Plain"),
 *   field_types = {"dp_date_time"},
 * )
 */
final class PlainFormatter extends AbstractFormatter {

  /**
   * {@inheritdoc}
   *
   * @param \Drupal\date_point\Plugin\Field\FieldType\DateTime\DateTimeItemList $items
   *
   * @return list<array>
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $site_timezone = $this->getTimezone();
    $elements = [];
    foreach ($items as $delta => $item) {
      \assert($item instanceof DateTimeItem);
      $format = $item::buildFormat($item->getPrecision());
      $elements[$delta] = [
        '#markup' => $item->getDTI()
          // The datetime must be presented in site timezone.
          ->setTimezone($site_timezone)
          ->format($format),
        '#cache' => ['contexts' => ['timezone']],
      ];
    }
    return $elements;
  }

}
