<?php

declare(strict_types=1);

namespace Drupal\date_point\Plugin\Field\FieldWidget\DateTime;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\date_point\Data\DateTimeBehavior as Behavior;
use Drupal\date_point\Plugin\Field\FieldType\DateTime\DateTimeItem;

/**
 * Plugin implementation of the 'date_point' widget.
 *
 * @FieldWidget(
 *   id = "dp_date_time_textfield",
 *   label = @Translation("Textfield"),
 *   field_types = {"dp_date_time"},
 * )
 */
final class TextfieldWidget extends AbstractWidget {

  /**
   * {@inheritdoc}
   *
   * @param \Drupal\date_point\Plugin\Field\FieldType\DateTime\DateTimeItemList $items
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $item = $items[$delta];
    \assert($item instanceof DateTimeItem);

    $value = NULL;
    if (!$item->isEmpty()) {
      // The value in of the input must be presented in default site timezone.
      $format = $item::buildFormat($item->getPrecision());
      $value = $item
        ->getDTI()
        ->setTimezone($this->getTimezone())
        ->format($format);
    }

    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => $value,
      // There is no point to edit this value when behavior is set to 'updated'.
      '#disabled' => Behavior::from($items->getSetting('behavior')) === Behavior::UPDATED,
    ];

    return $element;
  }

}
